@@ -215,17 +215,17 @@ static inline libGAP_Obj libGAP_NEW_INTPOS( libGAP_Obj gmp )
 *F  NEW_INTNEG( <gmp> )
 **
 **
-*/
-static inline libGAP_Obj libGAP_NEW_INTNEG( libGAP_Obj gmp )
+**
+static inline Obj NEW_INTNEG( Obj gmp )
 {
-  libGAP_Obj new;
+  Obj new;
 
-  new = libGAP_NewBag( libGAP_T_INTNEG, libGAP_SIZE_OBJ(gmp) );
-  memcpy( libGAP_ADDR_INT(new), libGAP_ADDR_INT(gmp), libGAP_SIZE_OBJ(gmp) );
+  new = NewBag( T_INTNEG, SIZE_OBJ(gmp) );
+  memcpy( ADDR_INT(new), ADDR_INT(gmp), SIZE_OBJ(gmp) );
 
   return new;
 }
-
+*/
 
 /****************************************************************************
 **
